==> elasticsearch-java-7.16.3-sources.jar: co/elastic/clients/elasticsearch/core/ExistsSourceResponse.java <==
/*
 * Licensed to Elasticsearch B.V. under one or more contributor
 * license agreements. See the NOTICE file distributed with
 * this work for additional information regarding copyright
 * ownership. Elasticsearch B.V. licenses this file to you under
 * the Apache License, Version 2.0 (the "License"); you may
 * not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

//----------------------------------------------------
// THIS CODE IS GENERATED. MANUAL EDITS WILL BE LOST.
//----------------------------------------------------

package co.elastic.clients.elasticsearch.core;

import co.elastic.clients.json.JsonpDeserializable;
import co.elastic.clients.json.JsonpDeserializer;
import co.elastic.clients.json.ObjectBuilderDeserializer;
import co.elastic.clients.json.ObjectDeserializer;
import co.elastic.clients.util.ObjectBuilder;
import jakarta.json.stream.JsonGenerator;
import java.util.Objects;

// typedef: _global.exists_source.Response

/**
 *
 * @see <a href=
 *      "https://github.com/elastic/elasticsearch-specification/tree/98036c3/specification/_global/exists_source/SourceExistsResponse.ts#L22-L24">API
 *      specification</a>
 */

public class ExistsSourceResponse {
	public ExistsSourceResponse() {
	}

	/**
	 * Singleton instance for {@link ExistsSourceResponse}.
	 */
	public static final ExistsSourceResponse _INSTANCE = new ExistsSourceResponse();

	public static final JsonpDeserializer<ExistsSourceResponse> _DESERIALIZER = JsonpDeserializer
			.fixedValue(ExistsSourceResponse._INSTANCE);

}

==> elasticsearch-java-8.4.2-sources.jar: co/elastic/clients/elasticsearch/core/ExistsSourceResponse.java <==
/*
 * Licensed to Elasticsearch B.V. under one or more contributor
 * license agreements. See the NOTICE file distributed with
 * this work for additional information regarding copyright
 * ownership. Elasticsearch B.V. licenses this file to you under
 * the Apache License, Version 2.0 (the "License"); you may
 * not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

//----------------------------------------------------
// THIS CODE IS GENERATED. MANUAL EDITS WILL BE LOST.
//----------------------------------------------------

package co.elastic.clients.elasticsearch.core;

import co.elastic.clients.json.JsonpDeserializable;
import co.elastic.clients.json.JsonpDeserializer;
import co.elastic.clients.json.ObjectBuilderDeserializer;
import co.elastic.clients.json.ObjectDeserializer;
import co.elastic.clients.util.ObjectBuilder;
import jakarta.json.stream.JsonGenerator;
import java.util.Objects;

// typedef: _global.exists_source.Response

/**
 *
 * @see <a href="../doc-files/api-spec.html#_global.exists_source.Response">API
 *      specification</a>
 */

public class ExistsSourceResponse {
	public ExistsSourceResponse() {
	}

	/**
	 * Singleton instance for {@link ExistsSourceResponse}.
	 */
	public static final ExistsSourceResponse _INSTANCE = new ExistsSourceResponse();

	public static final JsonpDeserializer<ExistsSourceResponse> _DESERIALIZER = JsonpDeserializer
			.fixedValue(ExistsSourceResponse._INSTANCE);

}
